@@ -14,7 +14,7 @@
     
     yi <- seq(-(N2 - 1), (N2), 1) * dy
     yi <- yi/theta
-    dd <- sqrt((matrix(xi, M, N)^2 + matrix(yi, M, N, byrow = TRUE)^2))/theta
+    dd <- sqrt((matrix(xi, M, N)^2 + matrix(yi, M, N, byrow = TRUE)^2))
     out <- matrix(kernel.function(dd, ...), nrow = M, ncol = N)
     out2 <- matrix(0, M, N)
     out2[M2, N2] <- 1
