@@ -15,7 +15,7 @@ out<- multWendlandGrid( grid.list,center, delta, coef)
 xg<- make.surface.grid( grid.list)
 test<-  Wendland2.2(  rdist( xg, center)/delta)%*% coef
 test.for.zero.flag<-1 
-test.for.zero( test, out, tag="Comparing FORTRAM grid eval to matrix vector multiplication")
+test.for.zero( test, out, tag="Comparing FORTRAN grid eval to matrix vector multiplication")
 
 
 
@@ -33,15 +33,16 @@ obj<- fastTps( x,y, theta=delta, lambda=.1)
 grid.list<- list( x= seq(0,1,,3), y=seq( 0,1,,4))
 xg<- make.surface.grid( grid.list)
 look0<- c(predict( obj, xg))
-look1<- predictSurface.fastTps( obj, grid.list)
-
-test.for.zero( look0, c(look1$z), tag="testing PredictSurface")
+look1<- predictSurface( obj, grid.list, extrap=TRUE)
+look2<-  predict.mKrig( obj, xg)
+test.for.zero( look0, c(look1$z), tag="testing PredictSurface and predict.fastTps")
+test.for.zero( look0, c(look2), tag="testing PredictSurface with slower mKrig predict")
 
 # new y
 set.seed(123)
  ynew<- rnorm( nc)
  look0<- c(predict( obj, xg, ynew=ynew))
- look1<- predictSurface.fastTps( obj, grid.list, ynew=ynew)
+ look1<- predictSurface( obj, grid.list, ynew=ynew, extrap=TRUE)
  look2<- c(predict(fastTps( x,ynew, theta=delta, lambda=.1) , xg, ynew=ynew))
  test.for.zero( look0, look2,tag="predict with ynew")
  test.for.zero( look0, c(look1$z), tag="predictSurface with ynew")
